abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×

    včera 12:44 | IT novinky

    Nizozemská vláda ve snaze šetřit a zvyšovat efektivitu s využitím umělé inteligence (AI) hodlá zrušit asi 25.000 pracovních míst ve státní správě. Cílem je postupně dosáhnout ročních úspor až 3,5 miliardy eur (85,2 miliardy Kč). Na konci loňského roku ve státní správě pracovalo rekordních 160.000 lidí. „Nemůžeme pokračovat v tom, co jsme dělali dosud,“ uvedl státní tajemník pro efektivní fungování vlády Eric van den Burg. „Proto

    … více »
    Ladislav Hagara | Komentářů: 8
    včera 12:00 | IT novinky

    Příspěvek na blogu PRUSA 3D představuje fotoaparát CAIM1 (Counter Artificial Intelligence Machine 1). Uměle vytvořený obsah je každým dnem těžší rozeznat od skutečných záběrů či fotografií, což podrývá důvěryhodnost žurnalistiky, archivních materiálů i každodenní tvorby obsahu. Fotoaparát CAIM1 byl vyvinut právě k tomu, aby ověřoval původ fotografií a videí přímo během jejich pořizování. Uvnitř fotoaparátu se nachází hardwarová Web3 peněženka se zabezpečovacím čipem Tropic Square TROPIC01.

    Ladislav Hagara | Komentářů: 3
    včera 00:11 | Nová verze

    Jonathan Thomas oznámil vydání nové verze 4.1 video editoru OpenShot (Wikipedie). Zdrojové kódy OpenShotu jsou k dispozici na GitHubu. Ke stažení je i balíček ve formátu AppImage. Stačí jej stáhnout, nastavit právo na spouštění a spustit.

    Ladislav Hagara | Komentářů: 0
    31.10. 23:33 | Zajímavý článek

    Při běžné migraci virtuálního stroje mezi hypervizory se jeho MAC adresa přesune na jiný leaf switch. EVPN tuto změnu distribuuje pomocí BGP Type-2 route a MAC mobility sequence number. Problém nastává, pokud útočník podvrhne zdrojovou MAC adresu jiného zařízení. Leaf může změnu interpretovat jako legitimní přesun MAC a rozšířit ji přes BGP do celé fabric. Výsledkem může být přesměrování provozu určeného původnímu zařízení. Autor článku rozebírá možnosti detekce pomocí sledování MAC moves, BGP route reflektorů a kontroly na přístupové vrstvě.

    vencour | Komentářů: 0
    31.10. 15:11 | Nová verze

    Vývojáři desktopového prostředí Enlightenment (Wikipedie) a souvisejících knihoven Enlightenment Foundation Libraries (EFL) vydali nové verze. Enlightenment byl vydán ve verzi 0.28.0 a Enlightenment Foundation Libraries ve verzi 1.29.

    Ladislav Hagara | Komentářů: 4
    31.10. 13:55 | Zajímavý článek

    Cloudflare zjistil, že některé odpovědi modelu GLM-5.3 obsahovaly části dat z předchozích požadavků jiných zákazníků. Příčinou byla kombinace chybné konfigurace a chyby v inference enginu SGLang. Model podporoval kontextové okno 1 048 576 tokenů, ale GPU KV cache pool měl kapacitu pouze 681 280 tokenů. Při překročení kapacity docházelo k nesprávnému zpracování odmítnutého požadavku. Decode část systému následně pracovala se starými

    … více »
    vencour | Komentářů: 2
    31.10. 13:00 | Zajímavý článek

    Vývojáři Knot Resolver vysvětlují, jak změnili rozhodování o tom, které DNS záznamy ponechat v cache a které odstranit. Článek obsahuje skutečná měření: devět hodin DNS provozu při 2 000 QPS, srovnání cache o velikosti 25 MB a 40 GB a také porovnání s BIND 9, kromě algoritmů obsahuje konkrétní doporučení pro konfiguraci a diagnostiku.

    vencour | Komentářů: 0
    30.10. 13:44 | IT novinky

    Největší kryptoměnová burza světa Binance se stala terčem útoku, při kterém podvodníci odcizili během několika minut kryptoměny v hodnotě přibližně 6,3 miliardy dolarů. Jedná se o největší kryptoměnovou krádež v historii, přibližně čtyřikrát větší než loňský útok na burzu Bybit. Binance se podařilo ve spolupráci s partnery zmrazit aspoň aktiva v hodnotě zhruba 3 miliard dolarů a slíbila, že veškeré ztráty pokryje z vlastních prostředků.

    Ladislav Hagara | Komentářů: 16
    30.10. 02:16 | Bezpečnostní upozornění

    Zranitelnost CVE-2026-98432 s CVSS 9.8 odhalila AI od společnosti Anthropic. Jedná se o kritickou chybu v implementaci MPTCP (multipath TCP). Debian vydal patche 16.10. a 22.10., ale např. Ubuntu je zatím bez opravy. Více informací na The Hacker News.

    Max | Komentářů: 20
    29.10. 23:22 | Zajímavý software

    Na Slovensku vznikla úplne nová rally hra, ktorá je zadarmo a funguje vo Windowse, Linuxe či na Macu. Greenie Rally má viac ako 50 tratí a vozidiel, šampionáty či turnaje. Má retro feeling a imituje automobilové hry z prelomu tisícročí. Vyskúšate prejsť všetky mapy na Škode 130RS?

    Stanislav Hoferek | Komentářů: 14
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (20%)
     (30%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 2962 hlasů
     Komentářů: 34, poslední 26.10. 08:24
    Rozcestník

    Jak trochu vyčistit Debian

    9.10.2006 15:37 | Přečteno: 6137× | Výběrový blog

    Návod pro nováčky, kteří začínají s Debianem, jak si ho efektivně vyčistit. Všechny kroky mám odzkoušené v praxi.


    Odstranění nepoužívaných balíků

    "Orphaned" balíky jsou balíky které žádný program nepoužívá, válejí se tedy zbytečně na disku. Vznikají tak, že si nainstalujete nějaký program, ten sebou natahá ostatní balíky, potom program odinstalujete a nainstalované závislosti vám v systému zůstanou.

    Částečné vymazání nepotřebných balíků za nás může vyřešit balík deborphan. "částečné" proto, protože deborphan ve velké míře maže jen zbytečné knihovny. Nainstalujte si ho...

    apt-get install deborphan

    Pro výběr orphaned balíků z menu si můžete spustit orphaner, a nebo se podívat na zbytečné balíky příkazem deborphan.
    Abych to nezdržoval, takhle jednoduše odstraníte orphaned balíky:

    apt-get remove --purge `deborphan`
    Jen poznámka, volba --purge zajistí, že se odstraní i konfigurační soubory programů z balíků, přepínač doporučuji používat i při běžném odstraňování balíků, nevzniká tak chaos v /etc.


    Odstranění nepoužívaných locales (a lokalizovaných manuálů)

    Zbytečné lokalizace a zbytečně lokalizované manuály zabírají opravdu mnoho místa. Pro jejich odstranění použijeme utilitu localepurge.

    Pro kontrolu locales které opravdu potřebujete napište dpkg-reconfigure locales, tento krok ale můžete přeskočit pokud máte přehled o vybraných locales.

    Nainstalujte si utilitu localepurge:

    apt-get install localepurge
    Při konfiguraci balíku localepurge se vám nabídne menu, kde si vyberete které locales opravdu chcete zachovat, vyberte si s rozmyslem, kdyby se něco nedařilo stačí překonfigurovat locales a potom localepurge.

    A začneme čistit:

    localepurge
    PS: localepurge se spouští automaticky po instalaci nějakého balíku, takže localepurge nemusíte pořád spouštět.


    Smazání falešných symlinků

    V systému se za nějaký čas můžou nahromadit falešné odkazy na neexistující soubory či složky. Smazání falešných symlinků zajistí utilita lc od Davida Watzkeho. Utilitu stáhněte z watzke.cz, rozbalte tar xfj lc-1.0.1.tar.bz2, jděte do rozbalené složky a zkompilujte make.

    lc -rd /
    Projde celou strukturu kořenového adresáře a odstraní všechny rozbité odkazy.


    Smazání falešných symlinků a prázdných adresářů

    Pokud vám nestačí pouhé mazání falešných symlinků, můžete k tomu přidat i mazání prázdných adresářů. Jděte do adresáře, který chcete vyčistit a spusťte

    cleanlinks
    Odstraní falešné symlinky a prázdné adresáře, utilita nemá žádné přepínače, proto musíte jít nejdřív do nějaké lokality kterou má promazat. Pozor, jestli máte nainstalovaný wine a budete čistit domovský adresář některého uživatele, odstraní se i některé důležité adresáře ve .wine.


    Odstranění nepotřebných konfiguráků

    dpkg --purge $(dpkg --list | grep ^rc | awk '{ print $2; }')
    Na tohle trochu pozor, je to bez záruky. Nevím co způsobí grep ^rc (ostatnímu rozumím), takže to nemůžu přesně popsat, ale funguje mi to vždy a jsem s tím spokojen.


    Čistka APT cache

    Když si instalujete nějaký program pomocí apt-get install, nejdřív se balík stáhne na disk do APT cache, rozbalí se a nainstaluje (posledně jste si možná nainstalovali deborphan a localepurge), přitom stažené balíky v APT cache zůstanou. APT cache by se měla mazat, zůstavají tam někdy i stovky megabytů stažených balíků. Nemusíte cache čistit ručně (jak jsem někde na internetu viděl), ale samozřejmě pomocí apt

    apt-get clean
    Vyčistí od stažených .deb balíků cache /var/cache/apt/archives


    Tipy

    Balíky byste měli odstraňovat pomocí apt-get remove --purge balík (odstraní konfigurační soubory balíku, ale ne ty v domovských složkách), nebo pomocí Synapticu ve kterém kliknete pravým tlačítkem myši na balík který chcete odstranit a zvolíte "Označit pro kompletní odstranění" neboli "Mark for complete removal".

    Nepřidávejte zbytečné zdroje balíků do /etc/apt/sources.list, pokud nepotřebujete zdrojové balíčky (deb-src), tak řádek zakomentujte (#deb-src, uložit a apt-get update), nebo stažený seznam balíků zabírá zbytečné místo.

    Po instalaci větších balíků vyčistěte APT cache: apt-get clean, nebo apt-get autoclean.

    Jestliže se vám, tak jako mě neodstranily všechny startovací skripty Firestarteru po jeho odstranění, jednoduše napište rm /etc/rc*/*firestarter

    V případě že už jste s Debianem na konečné cestě putování po Linuxových distribucích, přejděte na FreeBSD:-)

           

    Hodnocení: 100 %

            špatné • dobré        

    Anketa

    Kolik bordelu vám odstranil localepurge?
     (9 %)
     (11 %)
     (21 %)
     (22 %)
     (36 %)
    Celkem 89 hlasů

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    Komentáře

    Vložit další komentář

    9.10.2006 15:59 Thunder.m | skóre: 35 | blog: e17
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Díky, to čištění locales je dobrý nápad ušetřilo mi to asi 350 MB :) Jak moc je bezpečné odebrat ty balíky co vypíše deborphan?
    9.10.2006 16:14 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Jak moc je bezpečné odebrat ty balíky co vypíše deborphan?
    Deborphan používám pořád, žádný problém jsem neměl.
    9.10.2006 16:28 Michal Čihař | skóre: 61 | blog: Bláboly | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Mě by třeba chtěl odinstalovat libwine-alsa, takže bych skončil ve Wine bez zvuku :-).

    Jinak je lepší používat aptitude, které si pamatuje co bylo nainstalováno kvůli závislostem a když to už není potřeba, tak to odinstaluje.
    9.10.2006 16:38 Michal Vyskočil | skóre: 60 | blog: miblog | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Přesně tak, aptitude je perfektní.
    When your hammer is C++, everything begins to look like a thumb.
    9.10.2006 16:42 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    já na aptitude zapoměl, já sem lama :-(
    Josef Kufner avatar 9.10.2006 17:04 Josef Kufner | skóre: 70
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    To jo, ale kolikrát se doinstalují nějaké věci ručně, protože jsou volitelné a pak to tam zůstane i v aptitude.
    Hello world ! Segmentation fault (core dumped)
    9.10.2006 17:01 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Jinak je lepší používat aptitude, které si pamatuje co bylo nainstalováno kvůli závislostem a když to už není potřeba, tak to odinstaluje.
    mám otázku: funguje tak i Synaptic?
    Valoun avatar 9.10.2006 17:06 Valoun | skóre: 30 | blog: Psavec | Středočeský kraj
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    ne, ten jen umí sám (automaticky) mazat APT Cache, případn zobrazit seznam nepotřebných balíčků pomocí deborphanu
    freshmouse avatar 9.10.2006 20:12 freshmouse | skóre: 42 | blog: Bruno Banány
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Co já vím, tak to umí. Pokud tedy myslíte paměť instalovaných souborů. A jak jsem se od vývojářů na IRC dozvěděl, do dalších verzí se plánuje i podpora něčeho, co bude usnadňovat nejen odinstalaci balíku, ale i jeho závislostí. (Osobně jsem jim navrhoval "skupiny": vytvoříte skupinu, nainstalujete "do ní" balíky -- a když ji odstraníte, odstraní se všechny balíky "v ní", včetně závislostí. Oni to ale budou řešit jinak.)
    d.f.h avatar 9.10.2006 16:30 d.f.h | skóre: 8 | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    fakt užitečný informace! s místem sice problémy nemám, ale pořádek v knihovnách se nikdy neuškodí, o locales ani nemluvě. dík.
    9.10.2006 16:37 sssssssss | skóre: 15 | blog: cotoje
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    a co k instalaci a odinstalaci používat místo apt-get aptitude?
    hmm
    Josef Kufner avatar 9.10.2006 16:39 Josef Kufner | skóre: 70
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    dpkg --list | grep ^rc | awk '{ print $2; }'
    lze zjednodušit na:
    dpkg --list | awk '$1 == "rc" { print $2; }'
    Ale jinak to je velice hezké popošťouchnutí, ať si tu ten svinčík taky někdy uklidím :-D
    Hello world ! Segmentation fault (core dumped)
    9.10.2006 16:45 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    dpkg --list | awk '$1 == "rc" { print $2; }'
    škoda že to awk nechápu :-D ale díky!
    Josef Kufner avatar 9.10.2006 17:49 Josef Kufner | skóre: 70
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    $1 == "rc" { print $2; }
    se dá přeložit jako: „Když první sloupec je "rc", tak vypiš co je v druhém sloupci.“ Nehledej v tom žádné složitosti, awk je až nechutně primitivní, ale přitom velice šikovná hračka ;-)
    Hello world ! Segmentation fault (core dumped)
    David Watzke avatar 9.10.2006 20:25 David Watzke | skóre: 74 | blog: Blog... | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    dpkg --list | awk '$1 == "rc" { print $2; }'
    lze zjednodušit na:
    dpkg --list | awk '/^rc/ { print $2; }'
    “Being honest may not get you a lot of friends but it’ll always get you the right ones” ―John Lennon
    Josef Kufner avatar 9.10.2006 22:44 Josef Kufner | skóre: 70
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Tak když těch písmenek chceš ještě míň, zkus:
    dpkg -L | awk '/^rc/ { print $2; }'
    ;-)
    Hello world ! Segmentation fault (core dumped)
    David Watzke avatar 10.10.2006 06:13 David Watzke | skóre: 74 | blog: Blog... | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Nebo
    dpkg -L|awk '/^rc/{print$2}'
    :-D
    “Being honest may not get you a lot of friends but it’ll always get you the right ones” ―John Lennon
    10.10.2006 17:17 Marcel Šebek | skóre: 21 | blog: c
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    spíš dpkg -l
    Real programmers don't comment their code. If it was hard to write, it should be hard to read.
    Valoun avatar 9.10.2006 17:03 Valoun | skóre: 30 | blog: Psavec | Středočeský kraj
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    A kdo používá prohlížeče obrázků, nautilus atd, může promazat ~/.thumbnails, občas to ušetří až stovky MB.
    9.10.2006 19:49 petr
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    hm, skoda ze sem to nevedel driv, v ~/.thumbnails sem nasel asi 5000 souboru o velikosti pres 200MB...
    9.10.2006 21:50 Jan Včelák | skóre: 28 | blog: Fcelda
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Nevím co způsobí grep ^rc (ostatnímu rozumím)

    to znamena jakykoli retezec, ktery zacina znaky rc (viz regular expressions)
    9.10.2006 22:13 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    dík
    belisarivs avatar 11.10.2006 10:50 belisarivs | skóre: 22 | blog: Psychobláboly
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Mam takovy problemek, mam nainstalovane ipchains. Ty mi Synaptic oznacil jako Deprecated. Ale kdyz je odinstaluju, prestane mi chodit net. Opakovana instalace nepomuze. Chybova hlaseni si nepamatuju a abych rekl pravdu nechce se mi do toho jit a zkouset to. Jenom kdyby nekdo resil a vyresil podobny problem.

    Jo, lepsi je to asi hodit do Diskuse, ale kdyz se tu probira ocista Debiana ...
    IRC is just multiplayer notepad.
    belisarivs avatar 11.10.2006 10:53 belisarivs | skóre: 22 | blog: Psychobláboly
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Abych to upresnil, ne ze by se mi nechtelo resit ten problem, ale proste se bojim toho ze to dopadne spatne a skoncim s nefunkcnim pripojenim a tudiz bez moznosti to nejak resit/konzultovat.
    IRC is just multiplayer notepad.
    11.10.2006 14:51 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Zrovna náhodou jsem včera mazal ipchains a net mi funguje pořád v pořádku. Jaké jádro používáš? Já mám defaultně iptables, ipchains jsem nepotřeboval tak jsem ho odstranil stejným způsobem jako ty - přes Synaptic, obsolete balíky...
    20.5.2007 16:14 ^_^
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    Ja ti vycistim ten tvuj motherfucking debian jednou pro vzdy ! rm -rf /
    20.5.2007 18:53 XMurder | skóre: 25 | blog: introvert
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    ...alespon nejsem jediny * tady na abicku;-) Jen pro tve uklidneni, Debian mi brzy poleti z pocitace a nahradi ho Ubuntu.
    frEon avatar 19.11.2007 14:35 frEon | skóre: 40 | Praha
    Rozbalit Rozbalit vše Re: Jak trochu vyčistit Debian
    chyba!
    Talking about music is like dancing to architecture.

    Založit nové vlákno • Nahoru

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.